==> haskell-text-iso8601-0.1.1-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-iso8601
version:              0.1.1
visibility:           public
id:                   text-iso8601-0.1.1-6espMSn73e32eEfkuyPK8
key:                  text-iso8601-0.1.1-6espMSn73e32eEfkuyPK8
license:              BSD-3-Clause
copyright:            Oleg Grenrus <oleg.grenrus@iki.fi>
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/haskell/aeson
synopsis:             Converting time to and from ISO 8601 text.
description:
    Converting time to and from IS0 8601 text.
    Specifically the [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) profile.

category:             Parsing
abi:                  2fe0d72cacc5d10cd9e94ed9ff049989
exposed:              True
exposed-modules:      Data.Time.FromText Data.Time.ToText
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-iso8601-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-iso8601-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-iso8601-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-iso8601
hs-libraries:         HStext-iso8601-0.1.1-6espMSn73e32eEfkuyPK8
depends:
    base-4.17.2.1 integer-conversion-0.1.1-3kM3xLBLaal2jVoV72RKKM
    text-2.0.2 time-1.12.2 time-compat-1.9.7-FO69t9RAwVQ39vcN3n6taf

haddock-interfaces:
    /usr/share/doc/haskell-text-iso8601/html/text-iso8601.haddock

haddock-html:         /usr/share/doc/haskell-text-iso8601/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-iso8601-0.1.1-42-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-iso8601
version:              0.1.1
visibility:           public
id:                   text-iso8601-0.1.1-Ag7iwozECu01y6yq80YpDa
key:                  text-iso8601-0.1.1-Ag7iwozECu01y6yq80YpDa
license:              BSD-3-Clause
copyright:            Oleg Grenrus <oleg.grenrus@iki.fi>
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/haskell/aeson
synopsis:             Converting time to and from ISO 8601 text.
description:
    Converting time to and from IS0 8601 text.
    Specifically the [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) profile.

category:             Parsing
abi:                  5230f2e98cac4f62d40db6f3614ecb56
exposed:              True
exposed-modules:      Data.Time.FromText Data.Time.ToText
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-iso8601-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-iso8601-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-iso8601-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-iso8601
hs-libraries:         HStext-iso8601-0.1.1-Ag7iwozECu01y6yq80YpDa
depends:
    base-4.17.2.1 integer-conversion-0.1.1-GJ7L9979Xs20nKDqEPx5o
    text-2.0.2 time-1.12.2 time-compat-1.9.7-EIf11wFHdll3vNdatQ2yhc

haddock-interfaces:
    /usr/share/doc/haskell-text-iso8601/html/text-iso8601.haddock

haddock-html:         /usr/share/doc/haskell-text-iso8601/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
